4.1. umbra.components.addons.projectsExplorer.models — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.1. umbra.components.addons.projectsExplorer.models

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer` Component Interface class Models.

Others:

## 4.1.1. Module Attributes

`umbra.components.addons.projectsExplorer.models.` `LOGGER`

## 4.1.2. Classes

class `umbra.components.addons.projectsExplorer.models.` `ProjectsProxyModel`(parent, *args, **kwargs)

  Bases: `PyQt4.QtGui.QSortFilterProxyModel`

  This class defines the proxy Model used the by `umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer` Component Interface class.

  Parameters: | parent – Object parent. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `filterAcceptsRow`(row, parent)

    This method reimplements the `QSortFilterProxyModel.filterAcceptsRow()` method.

    Parameters: | row – Source row. ( Integer ) parent – Source parent. ( QModelIndex )
    Returns: | Filter result ( Boolean )

  `data`(index, role=0)

    This method reimplements the `QSortFilterProxyModel.data()` method.

    Parameters: | index – Index. ( QModelIndex ) role – Role. ( Integer )
    Returns: | Data. ( QVariant )

  `getNode`(index)

    This method returns the Node at given index.

    Parameters: | index – Index. ( QModelIndex )
    Returns: | Node. ( AbstractCompositeNode )

  `getAttribute`(*args)

    This method reimplements requisite method.

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »